@@ -1,21 +1,21 @@
 package Dist::Zilla::Plugin::Prereqs::EnsureVersion;
 
-our $DATE = '2017-07-04'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-07-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Moose;
-with 'Dist::Zilla::Role::InstallTool';
+with 'Dist::Zilla::Role::AfterBuild';
 
 use namespace::autoclean;
 
 use Config::IOD::Reader;
 use File::HomeDir;
 
-sub setup_installer {
+sub after_build {
     my ($self) = @_;
 
     state $pmversions = do {
@@ -66,7 +66,7 @@ Dist::Zilla::Plugin::Prereqs::EnsureVersion - Make sure that prereqs have minimu
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::Prereqs::EnsureVersion (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureVersion), released on 2017-07-04.
+This document describes version 0.03 of Dist::Zilla::Plugin::Prereqs::EnsureVersion (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureVersion), released on 2017-07-07.
 
 =head1 SYNOPSIS
 
